summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/state.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:35 -0600
commitc0f375feba0103bed2bac1b1f05e76e9ae28fa89 (patch)
tree9c30a9097d650343df41d867f0e008769529eb08 /kpat/freecell-solver/state.h
parent0e2b76239f354a9eead0b4e37d86d390ec57ffa9 (diff)
downloadtdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.tar.gz
tdegames-c0f375feba0103bed2bac1b1f05e76e9ae28fa89.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kpat/freecell-solver/state.h')
-rw-r--r--kpat/freecell-solver/state.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpat/freecell-solver/state.h b/kpat/freecell-solver/state.h
index 302d6d9a..e52b717c 100644
--- a/kpat/freecell-solver/state.h
+++ b/kpat/freecell-solver/state.h
@@ -77,7 +77,7 @@ struct fcs_struct_state_with_locations_t
int depth;
int visited;
int visited_iter;
- int num_active_tqchildren;
+ int num_active_children;
int scan_visited[MAX_NUM_SCANS_BUCKETS];
};
@@ -237,7 +237,7 @@ struct fcs_struct_state_with_locations_t
int depth;
int visited;
int visited_iter;
- int num_active_tqchildren;
+ int num_active_children;
int scan_visited[MAX_NUM_SCANS_BUCKETS];
};
@@ -508,11 +508,11 @@ struct fcs_struct_state_with_locations_t
* */
int visited_iter;
/*
* This is the number of direct tqchildren of this state which were not
* yet declared as dead ends. Once this counter reaches zero, this
* state too is declared as a dead end.
* */
- int num_active_tqchildren;
+ int num_active_children;
/*
* This is a vector of flags - one for each scan. Each indicates whether
* its scan has already visited this state
@@ -508,11 +508,11 @@ struct fcs_struct_state_with_locations_t
int visited_iter;
/*
- * This is the number of direct tqchildren of this state which were not
+ * This is the number of direct children of this state which were not
* yet declared as dead ends. Once this counter reaches zero, this
* state too is declared as a dead end.